@@ -4,17 +4,18 @@ NULL
 
 
 # The 'indicator' class holds indicator definitions
-# An indicator maps a data.frame to a single number.
 
 #' Define indicators for data
 #' 
-#' \bold{This feature is currently experimental and may change in future versions}
+#' An indicator maps a data frame, or each record in a data frame to a number.
+#' The purpose of this class is to store and apply expressions that define
+#' indicators.
+#' 
 #' 
-#' \code{\link{indicator}}
 #' @param ... A comma-separated list of indicator definitions
 #' @param .file (optional) A character vector of file locations
 #' 
-#' @seealso \code{\link{syntax}}
+#' @seealso \code{\link{syntax}}, \code{\link{add_indicators}}
 #' 
 #' @export
 #' @keywords internal
@@ -35,10 +36,10 @@ indicator <- function(..., .file, .data) new('indicator',..., .file=.file, .data
 #' can be constructed with  \code{\link{indicator}}.
 #'
 #' @section Exported S4 methods for \code{validator}:
-#'   \itemize{
+#'  \itemize{
 #'  \item{Methods inherited from \code{\link{expressionset}}}
-#'  \item{\code{\link{confront}}}
-#'  \item{\code{\link{compare}}}
+#'    \item{\code{\link{confront}}}
+#'    \item{\code{\link{compare}}}
 #' }
 #' 
 #'
@@ -92,4 +93,56 @@ setMethod("+", c("indicator","indicator"), function(e1, e2){
 })
 
 
+#' Add indicator values as columns to a data frame
+#'
+#' Compute and add externally defined indicators to data frame.
+#' If necessary, values are recycled over records.
+#'
+#' @param dat \code{[data.frame]}
+#' @param x   \code{[indicator]} or \code{[indication]} object. See examples.
+#'
+#' @return \code{dat} with extra columns defined by \code{x} attached.
+#'
+#' @examples
+#' ii <- indicator(
+#'  hihi = 2*sqrt(height)
+#'  , haha = log10(weight)
+#'  , lulz = mean(height)
+#'  , wo0t = median(weight)
+#' )
+#' 
+#' # note: mean and median are repeated
+#' add_indicators(women, ii)
+#'
+#' # compute indicators first, then add
+#' out <- confront(women, ii)
+#' add_indicators(women, out)
+#'
+#' @family indicators
+#'
+#' @export
+add_indicators <- function(dat, x){
+  if (inherits(x,"indicator")) x <- confront(dat, x)
+  vals <- values(x)
+  if (is.array(vals) && nrow(vals)==nrow(dat)){
+    cbind(dat, as.data.frame(values(x)))
+  } else { # vals is a list
+    n <- nrow(dat)
+    L <- lapply(vals, function(x){
+      if (nrow(x) == n){
+        x
+      } else {
+        y <- matrix(0, nrow=n, ncol=ncol(x))
+        y[,] <- x
+        colnames(y) <- colnames(x)
+        y
+      }
+    })
+    cbind(dat, do.call("cbind", L))
+  }
+}
+
+
+
+
 
